@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_resource_groups import ResourceGroupsClient
-    from mypy_boto3_resource_groups import (
+    from mypy_boto3_resource_groups.paginator import (
         ListGroupResourcesPaginator,
         ListGroupsPaginator,
         SearchResourcesPaginator,
@@ -39,7 +39,7 @@ __all__ = ("ListGroupResourcesPaginator", "ListGroupsPaginator", "SearchResource
 
 class ListGroupResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListGroupResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
+    [Paginator.ListGroupResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources)
     """
 
     def paginate(
@@ -49,13 +49,13 @@ class ListGroupResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListGroupResourcesOutputTypeDef]:
         """
-        [ListGroupResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
+        [ListGroupResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroupResources.paginate)
         """
 
 
 class ListGroupsPaginator(Boto3Paginator):
     """
-    [Paginator.ListGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
+    [Paginator.ListGroups documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups)
     """
 
     def paginate(
@@ -64,18 +64,18 @@ class ListGroupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListGroupsOutputTypeDef]:
         """
-        [ListGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
+        [ListGroups.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.ListGroups.paginate)
         """
 
 
 class SearchResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
+    [Paginator.SearchResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources)
     """
 
     def paginate(
         self, ResourceQuery: "ResourceQueryTypeDef", PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[SearchResourcesOutputTypeDef]:
         """
-        [SearchResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
+        [SearchResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/resource-groups.html#ResourceGroups.Paginator.SearchResources.paginate)
         """
