@@ -3,9 +3,11 @@ Main interface for resource-groups service type definitions.
 
 Usage::
 
-    from mypy_boto3.resource_groups.type_defs import GroupTypeDef
+    ```python
+    from mypy_boto3_resource_groups.type_defs import GroupIdentifierTypeDef
 
-    data: GroupTypeDef = {...}
+    data: GroupIdentifierTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
@@ -21,19 +23,19 @@ else:
 
 
 __all__ = (
+    "GroupIdentifierTypeDef",
+    "GroupQueryTypeDef",
     "GroupTypeDef",
+    "QueryErrorTypeDef",
+    "ResourceIdentifierTypeDef",
     "ResourceQueryTypeDef",
     "CreateGroupOutputTypeDef",
     "DeleteGroupOutputTypeDef",
     "GetGroupOutputTypeDef",
-    "GroupQueryTypeDef",
     "GetGroupQueryOutputTypeDef",
     "GetTagsOutputTypeDef",
     "GroupFilterTypeDef",
-    "QueryErrorTypeDef",
-    "ResourceIdentifierTypeDef",
     "ListGroupResourcesOutputTypeDef",
-    "GroupIdentifierTypeDef",
     "ListGroupsOutputTypeDef",
     "PaginatorConfigTypeDef",
     "ResourceFilterTypeDef",
@@ -44,6 +46,14 @@ __all__ = (
     "UpdateGroupQueryOutputTypeDef",
 )
 
+GroupIdentifierTypeDef = TypedDict(
+    "GroupIdentifierTypeDef", {"GroupName": str, "GroupArn": str}, total=False
+)
+
+GroupQueryTypeDef = TypedDict(
+    "GroupQueryTypeDef", {"GroupName": str, "ResourceQuery": "ResourceQueryTypeDef"}
+)
+
 _RequiredGroupTypeDef = TypedDict("_RequiredGroupTypeDef", {"GroupArn": str, "Name": str})
 _OptionalGroupTypeDef = TypedDict("_OptionalGroupTypeDef", {"Description": str}, total=False)
 
@@ -52,39 +62,6 @@ class GroupTypeDef(_RequiredGroupTypeDef, _OptionalGroupTypeDef):
     pass
 
 
-ResourceQueryTypeDef = TypedDict(
-    "ResourceQueryTypeDef",
-    {"Type": Literal["TAG_FILTERS_1_0", "CLOUDFORMATION_STACK_1_0"], "Query": str},
-)
-
-CreateGroupOutputTypeDef = TypedDict(
-    "CreateGroupOutputTypeDef",
-    {"Group": GroupTypeDef, "ResourceQuery": ResourceQueryTypeDef, "Tags": Dict[str, str]},
-    total=False,
-)
-
-DeleteGroupOutputTypeDef = TypedDict(
-    "DeleteGroupOutputTypeDef", {"Group": GroupTypeDef}, total=False
-)
-
-GetGroupOutputTypeDef = TypedDict("GetGroupOutputTypeDef", {"Group": GroupTypeDef}, total=False)
-
-GroupQueryTypeDef = TypedDict(
-    "GroupQueryTypeDef", {"GroupName": str, "ResourceQuery": ResourceQueryTypeDef}
-)
-
-GetGroupQueryOutputTypeDef = TypedDict(
-    "GetGroupQueryOutputTypeDef", {"GroupQuery": GroupQueryTypeDef}, total=False
-)
-
-GetTagsOutputTypeDef = TypedDict(
-    "GetTagsOutputTypeDef", {"Arn": str, "Tags": Dict[str, str]}, total=False
-)
-
-GroupFilterTypeDef = TypedDict(
-    "GroupFilterTypeDef", {"Name": Literal["resource-type"], "Values": List[str]}
-)
-
 QueryErrorTypeDef = TypedDict(
     "QueryErrorTypeDef",
     {
@@ -98,25 +75,50 @@ ResourceIdentifierTypeDef = TypedDict(
     "ResourceIdentifierTypeDef", {"ResourceArn": str, "ResourceType": str}, total=False
 )
 
-ListGroupResourcesOutputTypeDef = TypedDict(
-    "ListGroupResourcesOutputTypeDef",
-    {
-        "ResourceIdentifiers": List[ResourceIdentifierTypeDef],
-        "NextToken": str,
-        "QueryErrors": List[QueryErrorTypeDef],
-    },
+ResourceQueryTypeDef = TypedDict(
+    "ResourceQueryTypeDef",
+    {"Type": Literal["TAG_FILTERS_1_0", "CLOUDFORMATION_STACK_1_0"], "Query": str},
+)
+
+CreateGroupOutputTypeDef = TypedDict(
+    "CreateGroupOutputTypeDef",
+    {"Group": "GroupTypeDef", "ResourceQuery": "ResourceQueryTypeDef", "Tags": Dict[str, str]},
     total=False,
 )
 
-GroupIdentifierTypeDef = TypedDict(
-    "GroupIdentifierTypeDef", {"GroupName": str, "GroupArn": str}, total=False
+DeleteGroupOutputTypeDef = TypedDict(
+    "DeleteGroupOutputTypeDef", {"Group": "GroupTypeDef"}, total=False
+)
+
+GetGroupOutputTypeDef = TypedDict("GetGroupOutputTypeDef", {"Group": "GroupTypeDef"}, total=False)
+
+GetGroupQueryOutputTypeDef = TypedDict(
+    "GetGroupQueryOutputTypeDef", {"GroupQuery": "GroupQueryTypeDef"}, total=False
+)
+
+GetTagsOutputTypeDef = TypedDict(
+    "GetTagsOutputTypeDef", {"Arn": str, "Tags": Dict[str, str]}, total=False
+)
+
+GroupFilterTypeDef = TypedDict(
+    "GroupFilterTypeDef", {"Name": Literal["resource-type"], "Values": List[str]}
+)
+
+ListGroupResourcesOutputTypeDef = TypedDict(
+    "ListGroupResourcesOutputTypeDef",
+    {
+        "ResourceIdentifiers": List["ResourceIdentifierTypeDef"],
+        "NextToken": str,
+        "QueryErrors": List["QueryErrorTypeDef"],
+    },
+    total=False,
 )
 
 ListGroupsOutputTypeDef = TypedDict(
     "ListGroupsOutputTypeDef",
     {
-        "GroupIdentifiers": List[GroupIdentifierTypeDef],
-        "Groups": List[GroupTypeDef],
+        "GroupIdentifiers": List["GroupIdentifierTypeDef"],
+        "Groups": List["GroupTypeDef"],
         "NextToken": str,
     },
     total=False,
@@ -133,9 +135,9 @@ ResourceFilterTypeDef = TypedDict(
 SearchResourcesOutputTypeDef = TypedDict(
     "SearchResourcesOutputTypeDef",
     {
-        "ResourceIdentifiers": List[ResourceIdentifierTypeDef],
+        "ResourceIdentifiers": List["ResourceIdentifierTypeDef"],
         "NextToken": str,
-        "QueryErrors": List[QueryErrorTypeDef],
+        "QueryErrors": List["QueryErrorTypeDef"],
     },
     total=False,
 )
@@ -145,9 +147,9 @@ TagOutputTypeDef = TypedDict("TagOutputTypeDef", {"Arn": str, "Tags": Dict[str,
 UntagOutputTypeDef = TypedDict("UntagOutputTypeDef", {"Arn": str, "Keys": List[str]}, total=False)
 
 UpdateGroupOutputTypeDef = TypedDict(
-    "UpdateGroupOutputTypeDef", {"Group": GroupTypeDef}, total=False
+    "UpdateGroupOutputTypeDef", {"Group": "GroupTypeDef"}, total=False
 )
 
 UpdateGroupQueryOutputTypeDef = TypedDict(
-    "UpdateGroupQueryOutputTypeDef", {"GroupQuery": GroupQueryTypeDef}, total=False
+    "UpdateGroupQueryOutputTypeDef", {"GroupQuery": "GroupQueryTypeDef"}, total=False
 )
